==> webkitgtk_2.4.8.orig.tar.xz: webkitgtk-2.4.8/Source/WebCore/svg/SVGHKernElement.h <==
/*
 * Copyright (C) 2007 Eric Seidel <eric@webkit.org>
 * Copyright (C) 2007 Nikolas Zimmermann <zimmermann@kde.org>
 * Copyright (C) 2008 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef SVGHKernElement_h
#define SVGHKernElement_h

#if ENABLE(SVG_FONTS)
#include "SVGFontElement.h"

namespace WebCore {

class SVGHKernElement final : public SVGElement {
public:
    static PassRefPtr<SVGHKernElement> create(const QualifiedName&, Document&);

    void buildHorizontalKerningPair(SVGKerningMap&);

private:
    SVGHKernElement(const QualifiedName&, Document&);

    virtual InsertionNotificationRequest insertedInto(ContainerNode&) override;
    virtual void removedFrom(ContainerNode&) override;

    virtual bool rendererIsNeeded(const RenderStyle&) override { return false; }
};

NODE_TYPE_CASTS(SVGHKernElement)

} // namespace WebCore

#endif // ENABLE(SVG_FONTS)
#endif

==> webkitgtk-2.7.2.tar.xz: webkitgtk-2.7.2/Source/WebCore/svg/SVGHKernElement.h <==
/*
 * Copyright (C) 2007 Eric Seidel <eric@webkit.org>
 * Copyright (C) 2007 Nikolas Zimmermann <zimmermann@kde.org>
 * Copyright (C) 2008 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef SVGHKernElement_h
#define SVGHKernElement_h

#if ENABLE(SVG_FONTS)
#include "SVGFontElement.h"

namespace WebCore {

class SVGHKernElement final : public SVGElement {
public:
    static PassRefPtr<SVGHKernElement> create(const QualifiedName&, Document&);

    bool buildHorizontalKerningPair(SVGKerningPair& kerningPair) const;

private:
    SVGHKernElement(const QualifiedName&, Document&);

    virtual InsertionNotificationRequest insertedInto(ContainerNode&) override;
    virtual void removedFrom(ContainerNode&) override;

    virtual bool rendererIsNeeded(const RenderStyle&) override { return false; }
};

} // namespace WebCore

#endif // ENABLE(SVG_FONTS)
#endif
